package net.sourceforge.rapidprops;

import java.lang.reflect.Method;

import org.junit.Test;
import static org.junit.Assert.*;

public class PropsHelperNameTest {
	
	private static interface TestProps {
		int getSomeNumber();
		int getanotherNumber();
		int isSomeNumber();
		int get();
		int x();
		
		@Prop(key="length", defaultValue="0")
		int size();
		
		boolean isGood();
		boolean isbad();
		boolean getBad();

		@Prop(defaultValue="true")
		boolean isOk();
	}
	
	private String getPropertyName(String methodName) throws SecurityException, NoSuchMethodException {
		Method m = TestProps.class.getMethod(methodName);
		Prop prop = m.getAnnotation(Prop.class);
		return PropsHelper.getPropertyKey(m, prop);
	}
	
	@Test
	public void test1() throws SecurityException, NoSuchMethodException {
		String propertyName = getPropertyName("getSomeNumber");
		assertEquals("someNumber", propertyName);
	}
	
	@Test(expected = RapidPropsException.class)
	public void test2() throws SecurityException, NoSuchMethodException {
		getPropertyName("getanotherNumber");
	}
	
	@Test(expected = RapidPropsException.class)
	public void test3() throws SecurityException, NoSuchMethodException {
		getPropertyName("isSomeNumber");
	}
	
	@Test(expected = RapidPropsException.class)
	public void test4() throws SecurityException, NoSuchMethodException {
		getPropertyName("get");
	}
	
	@Test(expected = RapidPropsException.class)
	public void test5() throws SecurityException, NoSuchMethodException {
		getPropertyName("x");
	}
	
	@Test
	public void test6() throws SecurityException, NoSuchMethodException {
		String propertyName = getPropertyName("isGood");
		assertEquals("good", propertyName);
	}
	
	@Test(expected = RapidPropsException.class)
	public void test7() throws SecurityException, NoSuchMethodException {
		getPropertyName("isbad");
	}
	
	@Test(expected = RapidPropsException.class)
	public void test8() throws SecurityException, NoSuchMethodException {
		getPropertyName("getBad");
	}
	
	@Test
	public void test9() throws SecurityException, NoSuchMethodException {
		String propertyName = getPropertyName("isOk");
		assertEquals("ok", propertyName);
	}
}
